[Armadeus-commitlog] armadeus branch, buildroot-update, updated. armadeus-6.0-93-g5f77571
Brought to you by:
sszy
|
From: Sébastien S. <ss...@us...> - 2016-07-06 15:50:42
|
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "armadeus".
The branch, buildroot-update has been updated
via 5f775713d5ff81a2b48b7462044d0e6c92590dbd (commit)
via 9b93f83056b4089204912226f0c8c06fa38e4ad9 (commit)
from d8bdf6a805e1471f3c8aba6acd39a35d928ce53b (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 5f775713d5ff81a2b48b7462044d0e6c92590dbd
Author: Sébastien Szymanski <seb...@ar...>
Date: Wed Jul 6 17:49:06 2016 +0200
[TOOLS] opos6ul: add recovery script and binaries
commit 9b93f83056b4089204912226f0c8c06fa38e4ad9
Author: Sébastien Szymanski <seb...@ar...>
Date: Wed Jul 6 16:29:22 2016 +0200
[LINUX] OPOS6UL: bump to 4.7-rc6 and remove 4.6
-----------------------------------------------------------------------
Summary of changes:
buildroot/configs/opos6ul_defconfig | 2 +-
.../armadeus/opos6ul/opos6ul-linux-4.7-rc6.config | 1 +
...l-linux-4.6.config => opos6ul-linux-4.7.config} | 39 +-
...pos6ul-and-opos6uldev-add-initial-support.patch | 315 ----------
patches/linux/4.7-rc6 | 1 +
...pos6ul-and-opos6uldev-add-initial-support.patch | 632 ++++++++++++++++++++
software/uboot_recover/opos6ul-u-boot.img | Bin 0 -> 266464 bytes
software/uboot_recover/opos6ul-u-boot.spl | Bin 0 -> 35840 bytes
.../{apf6_recovery.py => opos6ul_recovery.py} | 16 +-
9 files changed, 671 insertions(+), 335 deletions(-)
create mode 120000 buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7-rc6.config
rename buildroot/target/device/armadeus/opos6ul/{opos6ul-linux-4.6.config => opos6ul-linux-4.7.config} (92%)
delete mode 100644 patches/linux/4.6/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch
create mode 120000 patches/linux/4.7-rc6
create mode 100644 patches/linux/4.7/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch
create mode 100644 software/uboot_recover/opos6ul-u-boot.img
create mode 100644 software/uboot_recover/opos6ul-u-boot.spl
copy software/uboot_recover/{apf6_recovery.py => opos6ul_recovery.py} (91%)
diff --git a/buildroot/configs/opos6ul_defconfig b/buildroot/configs/opos6ul_defconfig
index ba032ea..1af8651 100644
--- a/buildroot/configs/opos6ul_defconfig
+++ b/buildroot/configs/opos6ul_defconfig
@@ -22,7 +22,7 @@ BR2_CPU_NAME="imx6ul"
BR2_TARGET_ARMADEUS_SDRAM_SIZE="256"
BR2_LINUX_KERNEL=y
BR2_LINUX_KERNEL_CUSTOM_VERSION=y
-BR2_LINUX_KERNEL_CUSTOM_VERSION_VALUE="4.6"
+BR2_LINUX_KERNEL_CUSTOM_VERSION_VALUE="4.7-rc6"
BR2_LINUX_KERNEL_PATCH="../patches/linux/$(BR2_LINUX_KERNEL_VERSION)"
BR2_LINUX_KERNEL_USE_CUSTOM_CONFIG=y
BR2_LINUX_KERNEL_CUSTOM_CONFIG_FILE="$(BR2_BOARD_PATH)/$(BR2_BOARD_NAME)-linux-$(BR2_LINUX_KERNEL_VERSION).config"
diff --git a/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7-rc6.config b/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7-rc6.config
new file mode 120000
index 0000000..734ac7c
--- /dev/null
+++ b/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7-rc6.config
@@ -0,0 +1 @@
+opos6ul-linux-4.7.config
\ No newline at end of file
diff --git a/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.6.config b/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7.config
similarity index 92%
rename from buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.6.config
rename to buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7.config
index 6eb0ec5..c7f1530 100644
--- a/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.6.config
+++ b/buildroot/target/device/armadeus/opos6ul/opos6ul-linux-4.7.config
@@ -17,14 +17,11 @@ CONFIG_MODULE_UNLOAD=y
CONFIG_MODVERSIONS=y
CONFIG_MODULE_SRCVERSION_ALL=y
# CONFIG_BLK_DEV_BSG is not set
-CONFIG_ARCH_MULTI_V6=y
CONFIG_ARCH_MXC=y
-# CONFIG_MACH_MX31ADS is not set
-# CONFIG_MACH_BUG is not set
CONFIG_SOC_IMX6UL=y
CONFIG_HAVE_ARM_ARCH_TIMER=y
CONFIG_ARM_PSCI=y
-CONFIG_PREEMPT_VOLUNTARY=y
+CONFIG_PREEMPT=y
CONFIG_AEABI=y
CONFIG_HIGHMEM=y
CONFIG_CMA=y
@@ -43,7 +40,6 @@ CONFIG_NET=y
CONFIG_PACKET=y
CONFIG_UNIX=y
CONFIG_INET=y
-CONFIG_IP_MULTICAST=y
CONFIG_IP_PNP=y
CONFIG_IP_PNP_DHCP=y
# CONFIG_INET_XFRM_MODE_TRANSPORT is not set
@@ -67,11 +63,30 @@ CONFIG_DMA_CMA=y
CONFIG_IMX_WEIM=y
CONFIG_CONNECTOR=y
CONFIG_MTD=y
+CONFIG_MTD_CMDLINE_PARTS=y
+CONFIG_MTD_BLOCK=y
+CONFIG_MTD_CFI=y
+CONFIG_MTD_JEDECPROBE=y
+CONFIG_MTD_CFI_INTELEXT=y
+CONFIG_MTD_CFI_AMDSTD=y
+CONFIG_MTD_CFI_STAA=y
+CONFIG_MTD_PHYSMAP_OF=y
+CONFIG_MTD_DATAFLASH=y
CONFIG_MTD_M25P80=y
+CONFIG_MTD_SST25L=y
+CONFIG_MTD_NAND=y
+CONFIG_MTD_NAND_GPMI_NAND=y
+CONFIG_MTD_NAND_MXC=y
CONFIG_MTD_SPI_NOR=y
+CONFIG_SPI_FSL_QUADSPI=y
+CONFIG_MTD_UBI=y
+CONFIG_MTD_UBI_FASTMAP=y
+CONFIG_MTD_UBI_BLOCK=y
CONFIG_BLK_DEV_LOOP=y
CONFIG_BLK_DEV_RAM=y
CONFIG_BLK_DEV_RAM_SIZE=65536
+CONFIG_EEPROM_AT24=y
+CONFIG_EEPROM_AT25=y
CONFIG_SCSI=y
# CONFIG_SCSI_PROC_FS is not set
CONFIG_BLK_DEV_SD=y
@@ -129,6 +144,7 @@ CONFIG_MOUSE_PS2=m
CONFIG_MOUSE_PS2_ELANTECH=y
CONFIG_INPUT_TOUCHSCREEN=y
CONFIG_TOUCHSCREEN_IMX6UL_TSC=y
+CONFIG_INPUT_MISC=y
CONFIG_SERIO_SERPORT=m
# CONFIG_LEGACY_PTYS is not set
# CONFIG_DEVKMEM is not set
@@ -138,9 +154,11 @@ CONFIG_SERIAL_FSL_LPUART=y
CONFIG_SERIAL_FSL_LPUART_CONSOLE=y
# CONFIG_I2C_COMPAT is not set
CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX_GPIO=y
# CONFIG_I2C_HELPER_AUTO is not set
CONFIG_I2C_ALGOPCF=m
CONFIG_I2C_ALGOPCA=m
+CONFIG_I2C_GPIO=y
CONFIG_I2C_IMX=y
CONFIG_SPI=y
CONFIG_SPI_IMX=y
@@ -184,11 +202,9 @@ CONFIG_DRM_IMX_TVE=y
CONFIG_DRM_IMX_LDB=y
CONFIG_DRM_IMX_HDMI=y
CONFIG_FB_MXS=y
-CONFIG_BACKLIGHT_LCD_SUPPORT=y
CONFIG_LCD_CLASS_DEVICE=y
CONFIG_LCD_L4F00242T03=y
CONFIG_LCD_PLATFORM=y
-CONFIG_BACKLIGHT_CLASS_DEVICE=y
CONFIG_BACKLIGHT_PWM=y
CONFIG_BACKLIGHT_GPIO=y
CONFIG_FRAMEBUFFER_CONSOLE=y
@@ -252,11 +268,12 @@ CONFIG_LEDS_TRIGGER_BACKLIGHT=y
CONFIG_LEDS_TRIGGER_GPIO=y
CONFIG_RTC_CLASS=y
CONFIG_RTC_INTF_DEV_UIE_EMUL=y
+CONFIG_RTC_DRV_MXC=y
CONFIG_RTC_DRV_SNVS=y
CONFIG_DMADEVICES=y
+CONFIG_FSL_EDMA=y
CONFIG_IMX_SDMA=y
CONFIG_MXS_DMA=y
-# CONFIG_MX3_IPU is not set
CONFIG_STAGING=y
# CONFIG_IOMMU_SUPPORT is not set
CONFIG_IIO=y
@@ -264,7 +281,7 @@ CONFIG_VF610_ADC=y
CONFIG_PWM=y
CONFIG_PWM_FSL_FTM=y
CONFIG_PWM_IMX=y
-CONFIG_NVMEM=y
+CONFIG_RAS=y
CONFIG_NVMEM_IMX_OCOTP=y
CONFIG_EXT2_FS=y
CONFIG_EXT2_FS_XATTR=y
@@ -285,6 +302,8 @@ CONFIG_UDF_FS=m
CONFIG_MSDOS_FS=m
CONFIG_VFAT_FS=y
CONFIG_TMPFS=y
+CONFIG_JFFS2_FS=y
+CONFIG_UBIFS_FS=y
CONFIG_NFS_FS=y
CONFIG_NFS_V3_ACL=y
CONFIG_NFS_V4=y
@@ -304,8 +323,6 @@ CONFIG_PROVE_LOCKING=y
# CONFIG_FTRACE is not set
# CONFIG_ARM_UNWIND is not set
CONFIG_SECURITYFS=y
-CONFIG_CRYPTO_DEFLATE=y
-CONFIG_CRYPTO_LZO=y
CONFIG_CRYPTO_DEV_FSL_CAAM=y
CONFIG_CRYPTO_DEV_SAHARA=y
CONFIG_CRC_CCITT=m
diff --git a/patches/linux/4.6/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch b/patches/linux/4.6/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch
deleted file mode 100644
index 04698d7..0000000
--- a/patches/linux/4.6/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch
+++ /dev/null
@@ -1,315 +0,0 @@
-From b22204b2031d7ad3f6c5d21c96458488501be45a Mon Sep 17 00:00:00 2001
-From: =?UTF-8?q?S=C3=A9bastien=20Szymanski?=
- <seb...@ar...>
-Date: Thu, 2 Jun 2016 18:53:59 +0200
-Subject: [PATCH] ARM: dts: opos6ul and opos6uldev add initial support
-MIME-Version: 1.0
-Content-Type: text/plain; charset=UTF-8
-Content-Transfer-Encoding: 8bit
-
-Signed-off-by: Sébastien Szymanski <seb...@ar...>
----
- arch/arm/boot/dts/Makefile | 3 +-
- arch/arm/boot/dts/imx6ul-opos6ul.dtsi | 171 ++++++++++++++++++++++++++++++++
- arch/arm/boot/dts/imx6ul-opos6uldev.dts | 97 ++++++++++++++++++
- 3 files changed, 270 insertions(+), 1 deletion(-)
- create mode 100644 arch/arm/boot/dts/imx6ul-opos6ul.dtsi
- create mode 100644 arch/arm/boot/dts/imx6ul-opos6uldev.dts
-
-diff --git a/arch/arm/boot/dts/Makefile b/arch/arm/boot/dts/Makefile
-index 95c1923..4b775b5 100644
---- a/arch/arm/boot/dts/Makefile
-+++ b/arch/arm/boot/dts/Makefile
-@@ -374,7 +374,8 @@ dtb-$(CONFIG_SOC_IMX6SX) += \
- imx6sx-sdb-reva.dtb \
- imx6sx-sdb.dtb
- dtb-$(CONFIG_SOC_IMX6UL) += \
-- imx6ul-14x14-evk.dtb
-+ imx6ul-14x14-evk.dtb \
-+ imx6ul-opos6uldev.dtb
- dtb-$(CONFIG_SOC_IMX7D) += \
- imx7d-cl-som-imx7.dtb \
- imx7d-sbc-imx7.dtb \
-diff --git a/arch/arm/boot/dts/imx6ul-opos6ul.dtsi b/arch/arm/boot/dts/imx6ul-opos6ul.dtsi
-new file mode 100644
-index 0000000..992cdf9
---- /dev/null
-+++ b/arch/arm/boot/dts/imx6ul-opos6ul.dtsi
-@@ -0,0 +1,171 @@
-+/*
-+ * Copyright 2016 Armadeus Systems
-+ *
-+ * This file is dual-licensed: you can use it either under the terms
-+ * of the GPL or the X11 license, at your option. Note that this dual
-+ * licensing only applies to this file, and not this project as a
-+ * whole.
-+ *
-+ * a) This file is free software; you can redistribute it and/or
-+ * modify it under the terms of the GNU General Public License as
-+ * published by the Free Software Foundation; either version 2 of
-+ * the License, or (at your option) any later version.
-+ *
-+ * This file is distributed in the hope that it will be useful,
-+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
-+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-+ * GNU General Public License for more details.
-+ *
-+ * You should have received a copy of the GNU General Public
-+ * License along with this file; if not, write to the Free
-+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-+ * MA 02110-1301 USA
-+ *
-+ * Or, alternatively,
-+ *
-+ * b) Permission is hereby granted, free of charge, to any person
-+ * obtaining a copy of this software and associated documentation
-+ * files (the "Software"), to deal in the Software without
-+ * restriction, including without limitation the rights to use,
-+ * copy, modify, merge, publish, distribute, sublicense, and/or
-+ * sell copies of the Software, and to permit persons to whom the
-+ * Software is furnished to do so, subject to the following
-+ * conditions:
-+ *
-+ * The above copyright notice and this permission notice shall be
-+ * included in all copies or substantial portions of the Software.
-+ *
-+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-+ * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-+ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-+ * OTHER DEALINGS IN THE SOFTWARE.
-+ */
-+
-+#include "imx6ul.dtsi"
-+
-+&fec1 {
-+ pinctrl-names = "default";
-+ pinctrl-0 = <&pinctrl_enet1>;
-+ phy-mode = "rmii";
-+ phy-reset-duration = <1>;
-+ phy-reset-gpios = <&gpio4 2 GPIO_ACTIVE_LOW>;
-+ phy-handle = <ðphy1>;
-+ status = "okay";
-+
-+ mdio {
-+ #address-cells = <1>;
-+ #size-cells = <0>;
-+
-+ ethphy1: ethernet-phy@1 {
-+ compatible = "ethernet-phy-ieee802.3-c22";
-+ reg = <1>;
-+ interrupt-parent = <&gpio4>;
-+ interrupts = <16 IRQ_TYPE_LEVEL_LOW>;
-+ status = "okay";
-+ };
-+ };
-+};
-+
-+/* Bluetooth */
-+&uart8 {
-+ pinctrl-names = "default";
-+ pinctrl-0 = <&pinctrl_uart8>;
-+ fsl,uart-has-rtscts;
-+ //status = "okay";
-+};
-+
-+/* eMMC */
-+&usdhc1 {
-+ pinctrl-names = "default";
-+ pinctrl-0 = <&pinctrl_usdhc1>;
-+ bus-width = <8>;
-+ no-1-8-v;
-+ non-removable;
-+ status = "okay";
-+};
-+
-+/* WiFi */
-+&usdhc2 {
-+ pinctrl-names = "default";
-+ pinctrl-0 = <&pinctrl_usdhc2>;
-+ bus-width = <4>;
-+ no-1-8-v;
-+ //status = "okay";
-+
-+ #address-cells = <1>;
-+ #size-cells = <0>;
-+
-+ brcmf: bcrmf@1 {
-+ compatible = "brcm,bcm4329-fmac";
-+ reg = <1>;
-+ interrupt-parent = <&gpio2>;
-+ interrupts = <8 IRQ_TYPE_LEVEL_LOW>;
-+ interrupt-names = "host-wake";
-+ };
-+};
-+
-+&iomuxc {
-+ pinctrl_enet1: enet1grp {
-+ fsl,pins = <
-+ MX6UL_PAD_GPIO1_IO06__ENET1_MDIO 0x1b0b0
-+ MX6UL_PAD_GPIO1_IO07__ENET1_MDC 0x1b0b0
-+ MX6UL_PAD_ENET1_RX_ER__ENET1_RX_ER 0x130b0
-+ MX6UL_PAD_ENET1_RX_EN__ENET1_RX_EN 0x130b0
-+ MX6UL_PAD_ENET1_RX_DATA1__ENET1_RDATA01 0x130b0
-+ MX6UL_PAD_ENET1_RX_DATA0__ENET1_RDATA00 0x130b0
-+ MX6UL_PAD_ENET1_TX_DATA0__ENET1_TDATA00 0x1b0b0
-+ MX6UL_PAD_ENET1_TX_DATA1__ENET1_TDATA01 0x1b0b0
-+ MX6UL_PAD_ENET1_TX_EN__ENET1_TX_EN 0x1b0b0
-+ /* INT# */
-+ MX6UL_PAD_NAND_DQS__GPIO4_IO16 0x1b0b0
-+ /* RST# */
-+ MX6UL_PAD_NAND_DATA00__GPIO4_IO02 0x130b0
-+ MX6UL_PAD_ENET1_TX_CLK__ENET1_REF_CLK1 0x4001b031
-+ >;
-+ };
-+
-+ pinctrl_uart8: uart8grp {
-+ fsl,pins = <
-+ MX6UL_PAD_ENET2_TX_EN__UART8_DCE_RX 0x1b0b0
-+ MX6UL_PAD_ENET2_TX_DATA1__UART8_DCE_TX 0x1b0b0
-+ MX6UL_PAD_ENET2_RX_ER__UART8_DCE_RTS 0x1b0b0
-+ MX6UL_PAD_ENET2_TX_CLK__UART8_DCE_CTS 0x1b0b0
-+ /* BT_REG_ON */
-+ MX6UL_PAD_ENET2_RX_EN__GPIO2_IO10 0x130b0
-+ >;
-+ };
-+
-+ pinctrl_usdhc1: usdhc1grp {
-+ fsl,pins = <
-+ MX6UL_PAD_SD1_CMD__USDHC1_CMD 0x17059
-+ MX6UL_PAD_SD1_CLK__USDHC1_CLK 0x10059
-+ MX6UL_PAD_SD1_DATA0__USDHC1_DATA0 0x17059
-+ MX6UL_PAD_SD1_DATA1__USDHC1_DATA1 0x17059
-+ MX6UL_PAD_SD1_DATA2__USDHC1_DATA2 0x17059
-+ MX6UL_PAD_SD1_DATA3__USDHC1_DATA3 0x17059
-+ MX6UL_PAD_NAND_READY_B__USDHC1_DATA4 0x17059
-+ MX6UL_PAD_NAND_CE0_B__USDHC1_DATA5 0x17059
-+ MX6UL_PAD_NAND_CE1_B__USDHC1_DATA6 0x17059
-+ MX6UL_PAD_NAND_CLE__USDHC1_DATA7 0x17059
-+ >;
-+ };
-+
-+ pinctrl_usdhc2: usdhc2grp {
-+ fsl,pins = <
-+ MX6UL_PAD_LCD_DATA18__USDHC2_CMD 0x1b0b0
-+ MX6UL_PAD_LCD_DATA19__USDHC2_CLK 0x100b0
-+ MX6UL_PAD_LCD_DATA20__USDHC2_DATA0 0x1b0b0
-+ MX6UL_PAD_LCD_DATA21__USDHC2_DATA1 0x1b0b0
-+ MX6UL_PAD_LCD_DATA22__USDHC2_DATA2 0x1b0b0
-+ MX6UL_PAD_LCD_DATA23__USDHC2_DATA3 0x1b0b0
-+ /* WL_REG_ON */
-+ MX6UL_PAD_ENET2_RX_DATA1__GPIO2_IO09 0x130b0
-+ /* WL_IRQ */
-+ MX6UL_PAD_ENET2_RX_DATA0__GPIO2_IO08 0x1b0b0
-+ >;
-+ };
-+};
-diff --git a/arch/arm/boot/dts/imx6ul-opos6uldev.dts b/arch/arm/boot/dts/imx6ul-opos6uldev.dts
-new file mode 100644
-index 0000000..c31ad70
---- /dev/null
-+++ b/arch/arm/boot/dts/imx6ul-opos6uldev.dts
-@@ -0,0 +1,97 @@
-+/*
-+ * Copyright 2016 Armadeus Systems
-+ *
-+ * This file is dual-licensed: you can use it either under the terms
-+ * of the GPL or the X11 license, at your option. Note that this dual
-+ * licensing only applies to this file, and not this project as a
-+ * whole.
-+ *
-+ * a) This file is free software; you can redistribute it and/or
-+ * modify it under the terms of the GNU General Public License as
-+ * published by the Free Software Foundation; either version 2 of
-+ * the License, or (at your option) any later version.
-+ *
-+ * This file is distributed in the hope that it will be useful,
-+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
-+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-+ * GNU General Public License for more details.
-+ *
-+ * You should have received a copy of the GNU General Public
-+ * License along with this file; if not, write to the Free
-+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-+ * MA 02110-1301 USA
-+ *
-+ * Or, alternatively,
-+ *
-+ * b) Permission is hereby granted, free of charge, to any person
-+ * obtaining a copy of this software and associated documentation
-+ * files (the "Software"), to deal in the Software without
-+ * restriction, including without limitation the rights to use,
-+ * copy, modify, merge, publish, distribute, sublicense, and/or
-+ * sell copies of the Software, and to permit persons to whom the
-+ * Software is furnished to do so, subject to the following
-+ * conditions:
-+ *
-+ * The above copyright notice and this permission notice shall be
-+ * included in all copies or substantial portions of the Software.
-+ *
-+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-+ * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-+ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-+ * OTHER DEALINGS IN THE SOFTWARE.
-+ */
-+
-+/dts-v1/;
-+#include "imx6ul-opos6ul.dtsi"
-+
-+/ {
-+ model = "Armadeus Systems OPOS6UL Module on OPOS6UL Dev board";
-+ compatible = "armadeus,opos6uldev", "armadeus,opos6ul", "fsl,imx6ul";
-+
-+ chosen {
-+ stdout-path = &uart1;
-+ };
-+
-+ memory {
-+ reg = <0 0>; /* will be filled by U-Boot */
-+ };
-+};
-+
-+&uart1 {
-+ pinctrl-names = "default";
-+ pinctrl-0 = <&pinctrl_uart1>;
-+ status = "okay";
-+};
-+
-+&usbotg1 {
-+ pinctrl-names = "default";
-+ pinctrl-0 = <&pinctrl_usbotg1>;
-+ dr_mode = "otg";
-+ phy_type = "utmi";
-+ status = "okay";
-+};
-+
-+&usbotg2 {
-+ dr_mode = "host";
-+ phy_type = "utmi";
-+ status = "okay";
-+};
-+
-+&iomuxc {
-+ pinctrl_uart1: uart1grp {
-+ fsl,pins = <
-+ MX6UL_PAD_UART1_TX_DATA__UART1_DCE_TX 0x1b0b1
-+ MX6UL_PAD_UART1_RX_DATA__UART1_DCE_RX 0x1b0b1
-+ >;
-+ };
-+
-+ pinctrl_usbotg1: usbotg1grp {
-+ fsl,pins = <
-+ MX6UL_PAD_GPIO1_IO00__ANATOP_OTG1_ID 0x1b0b0
-+ >;
-+ };
-+};
---
-2.3.6
-
diff --git a/patches/linux/4.7-rc6 b/patches/linux/4.7-rc6
new file mode 120000
index 0000000..4b65d9d
--- /dev/null
+++ b/patches/linux/4.7-rc6
@@ -0,0 +1 @@
+4.7
\ No newline at end of file
diff --git a/patches/linux/4.7/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch b/patches/linux/4.7/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch
new file mode 100644
index 0000000..f1315ec
--- /dev/null
+++ b/patches/linux/4.7/0800-ARM-dts-opos6ul-and-opos6uldev-add-initial-support.patch
@@ -0,0 +1,632 @@
+From c753be8ed1438150ad427c5d8c84e86f9c70109f Mon Sep 17 00:00:00 2001
+From: =?UTF-8?q?S=C3=A9bastien=20Szymanski?=
+ <seb...@ar...>
+Date: Thu, 2 Jun 2016 18:53:59 +0200
+Subject: [PATCH 1/1] ARM: dts: opos6ul and opos6uldev add initial support
+MIME-Version: 1.0
+Content-Type: text/plain; charset=UTF-8
+Content-Transfer-Encoding: 8bit
+
+Signed-off-by: Sébastien Szymanski <seb...@ar...>
+---
+ arch/arm/boot/dts/Makefile | 1 +
+ arch/arm/boot/dts/imx6ul-opos6ul.dtsi | 181 ++++++++++++++
+ arch/arm/boot/dts/imx6ul-opos6uldev.dts | 407 ++++++++++++++++++++++++++++++++
+ 3 files changed, 589 insertions(+)
+ create mode 100644 arch/arm/boot/dts/imx6ul-opos6ul.dtsi
+ create mode 100644 arch/arm/boot/dts/imx6ul-opos6uldev.dts
+
+diff --git a/arch/arm/boot/dts/Makefile b/arch/arm/boot/dts/Makefile
+index 414b427..db9729f 100644
+--- a/arch/arm/boot/dts/Makefile
++++ b/arch/arm/boot/dts/Makefile
+@@ -393,6 +393,7 @@ dtb-$(CONFIG_SOC_IMX6SX) += \
+ imx6sx-sdb.dtb
+ dtb-$(CONFIG_SOC_IMX6UL) += \
+ imx6ul-14x14-evk.dtb \
++ imx6ul-opos6uldev.dtb \
+ imx6ul-pico-hobbit.dtb \
+ imx6ul-tx6ul-0010.dtb \
+ imx6ul-tx6ul-0011.dtb \
+diff --git a/arch/arm/boot/dts/imx6ul-opos6ul.dtsi b/arch/arm/boot/dts/imx6ul-opos6ul.dtsi
+new file mode 100644
+index 0000000..cd7ff48
+--- /dev/null
++++ b/arch/arm/boot/dts/imx6ul-opos6ul.dtsi
+@@ -0,0 +1,181 @@
++/*
++ * Copyright 2016 Armadeus Systems
++ *
++ * This file is dual-licensed: you can use it either under the terms
++ * of the GPL or the X11 license, at your option. Note that this dual
++ * licensing only applies to this file, and not this project as a
++ * whole.
++ *
++ * a) This file is free software; you can redistribute it and/or
++ * modify it under the terms of the GNU General Public License as
++ * published by the Free Software Foundation; either version 2 of
++ * the License, or (at your option) any later version.
++ *
++ * This file is distributed in the hope that it will be useful,
++ * but WITHOUT ANY WARRANTY; without even the implied warranty of
++ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
++ * GNU General Public License for more details.
++ *
++ * You should have received a copy of the GNU General Public
++ * License along with this file; if not, write to the Free
++ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
++ * MA 02110-1301 USA
++ *
++ * Or, alternatively,
++ *
++ * b) Permission is hereby granted, free of charge, to any person
++ * obtaining a copy of this software and associated documentation
++ * files (the "Software"), to deal in the Software without
++ * restriction, including without limitation the rights to use,
++ * copy, modify, merge, publish, distribute, sublicense, and/or
++ * sell copies of the Software, and to permit persons to whom the
++ * Software is furnished to do so, subject to the following
++ * conditions:
++ *
++ * The above copyright notice and this permission notice shall be
++ * included in all copies or substantial portions of the Software.
++ *
++ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
++ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
++ * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
++ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
++ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
++ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
++ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
++ * OTHER DEALINGS IN THE SOFTWARE.
++ */
++
++#include "imx6ul.dtsi"
++
++/ {
++ reg_3v3: regulator-3v3 {
++ compatible = "regulator-fixed";
++ regulator-name = "3V3";
++ regulator-min-microvolt = <3300000>;
++ regulator-max-microvolt = <3300000>;
++ };
++};
++
++&fec1 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_enet1>;
++ phy-mode = "rmii";
++ phy-reset-duration = <1>;
++ phy-reset-gpios = <&gpio4 2 GPIO_ACTIVE_LOW>;
++ phy-handle = <ðphy1>;
++ phy-supply = <®_3v3>;
++ status = "okay";
++
++ mdio: mdio {
++ #address-cells = <1>;
++ #size-cells = <0>;
++
++ ethphy1: ethernet-phy@1 {
++ compatible = "ethernet-phy-ieee802.3-c22";
++ reg = <1>;
++ interrupt-parent = <&gpio4>;
++ interrupts = <16 IRQ_TYPE_LEVEL_LOW>;
++ status = "okay";
++ };
++ };
++};
++
++/* Bluetooth */
++&uart8 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_uart8>;
++ fsl,uart-has-rtscts;
++ //status = "okay";
++};
++
++/* eMMC */
++&usdhc1 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_usdhc1>;
++ bus-width = <8>;
++ no-1-8-v;
++ non-removable;
++ status = "okay";
++};
++
++/* WiFi */
++&usdhc2 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_usdhc2>;
++ bus-width = <4>;
++ no-1-8-v;
++ //status = "okay";
++
++ #address-cells = <1>;
++ #size-cells = <0>;
++
++ brcmf: bcrmf@1 {
++ compatible = "brcm,bcm4329-fmac";
++ reg = <1>;
++ interrupt-parent = <&gpio2>;
++ interrupts = <8 IRQ_TYPE_LEVEL_LOW>;
++ interrupt-names = "host-wake";
++ };
++};
++
++&iomuxc {
++ pinctrl_enet1: enet1grp {
++ fsl,pins = <
++ MX6UL_PAD_GPIO1_IO06__ENET1_MDIO 0x1b0b0
++ MX6UL_PAD_GPIO1_IO07__ENET1_MDC 0x1b0b0
++ MX6UL_PAD_ENET1_RX_ER__ENET1_RX_ER 0x130b0
++ MX6UL_PAD_ENET1_RX_EN__ENET1_RX_EN 0x130b0
++ MX6UL_PAD_ENET1_RX_DATA1__ENET1_RDATA01 0x130b0
++ MX6UL_PAD_ENET1_RX_DATA0__ENET1_RDATA00 0x130b0
++ MX6UL_PAD_ENET1_TX_DATA0__ENET1_TDATA00 0x1b0b0
++ MX6UL_PAD_ENET1_TX_DATA1__ENET1_TDATA01 0x1b0b0
++ MX6UL_PAD_ENET1_TX_EN__ENET1_TX_EN 0x1b0b0
++ /* INT# */
++ MX6UL_PAD_NAND_DQS__GPIO4_IO16 0x1b0b0
++ /* RST# */
++ MX6UL_PAD_NAND_DATA00__GPIO4_IO02 0x130b0
++ MX6UL_PAD_ENET1_TX_CLK__ENET1_REF_CLK1 0x4001b031
++ >;
++ };
++
++ pinctrl_uart8: uart8grp {
++ fsl,pins = <
++ MX6UL_PAD_ENET2_TX_EN__UART8_DCE_RX 0x1b0b0
++ MX6UL_PAD_ENET2_TX_DATA1__UART8_DCE_TX 0x1b0b0
++ MX6UL_PAD_ENET2_RX_ER__UART8_DCE_RTS 0x1b0b0
++ MX6UL_PAD_ENET2_TX_CLK__UART8_DCE_CTS 0x1b0b0
++ /* BT_REG_ON */
++ MX6UL_PAD_ENET2_RX_EN__GPIO2_IO10 0x130b0
++ >;
++ };
++
++ pinctrl_usdhc1: usdhc1grp {
++ fsl,pins = <
++ MX6UL_PAD_SD1_CMD__USDHC1_CMD 0x17059
++ MX6UL_PAD_SD1_CLK__USDHC1_CLK 0x10059
++ MX6UL_PAD_SD1_DATA0__USDHC1_DATA0 0x17059
++ MX6UL_PAD_SD1_DATA1__USDHC1_DATA1 0x17059
++ MX6UL_PAD_SD1_DATA2__USDHC1_DATA2 0x17059
++ MX6UL_PAD_SD1_DATA3__USDHC1_DATA3 0x17059
++ MX6UL_PAD_NAND_READY_B__USDHC1_DATA4 0x17059
++ MX6UL_PAD_NAND_CE0_B__USDHC1_DATA5 0x17059
++ MX6UL_PAD_NAND_CE1_B__USDHC1_DATA6 0x17059
++ MX6UL_PAD_NAND_CLE__USDHC1_DATA7 0x17059
++ >;
++ };
++
++ pinctrl_usdhc2: usdhc2grp {
++ fsl,pins = <
++ MX6UL_PAD_LCD_DATA18__USDHC2_CMD 0x1b0b0
++ MX6UL_PAD_LCD_DATA19__USDHC2_CLK 0x100b0
++ MX6UL_PAD_LCD_DATA20__USDHC2_DATA0 0x1b0b0
++ MX6UL_PAD_LCD_DATA21__USDHC2_DATA1 0x1b0b0
++ MX6UL_PAD_LCD_DATA22__USDHC2_DATA2 0x1b0b0
++ MX6UL_PAD_LCD_DATA23__USDHC2_DATA3 0x1b0b0
++ /* WL_REG_ON */
++ MX6UL_PAD_ENET2_RX_DATA1__GPIO2_IO09 0x130b0
++ /* WL_IRQ */
++ MX6UL_PAD_ENET2_RX_DATA0__GPIO2_IO08 0x1b0b0
++ >;
++ };
++};
+diff --git a/arch/arm/boot/dts/imx6ul-opos6uldev.dts b/arch/arm/boot/dts/imx6ul-opos6uldev.dts
+new file mode 100644
+index 0000000..5e786bf
+--- /dev/null
++++ b/arch/arm/boot/dts/imx6ul-opos6uldev.dts
+@@ -0,0 +1,407 @@
++/*
++ * Copyright 2016 Armadeus Systems
++ *
++ * This file is dual-licensed: you can use it either under the terms
++ * of the GPL or the X11 license, at your option. Note that this dual
++ * licensing only applies to this file, and not this project as a
++ * whole.
++ *
++ * a) This file is free software; you can redistribute it and/or
++ * modify it under the terms of the GNU General Public License as
++ * published by the Free Software Foundation; either version 2 of
++ * the License, or (at your option) any later version.
++ *
++ * This file is distributed in the hope that it will be useful,
++ * but WITHOUT ANY WARRANTY; without even the implied warranty of
++ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
++ * GNU General Public License for more details.
++ *
++ * You should have received a copy of the GNU General Public
++ * License along with this file; if not, write to the Free
++ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
++ * MA 02110-1301 USA
++ *
++ * Or, alternatively,
++ *
++ * b) Permission is hereby granted, free of charge, to any person
++ * obtaining a copy of this software and associated documentation
++ * files (the "Software"), to deal in the Software without
++ * restriction, including without limitation the rights to use,
++ * copy, modify, merge, publish, distribute, sublicense, and/or
++ * sell copies of the Software, and to permit persons to whom the
++ * Software is furnished to do so, subject to the following
++ * conditions:
++ *
++ * The above copyright notice and this permission notice shall be
++ * included in all copies or substantial portions of the Software.
++ *
++ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
++ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
++ * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
++ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
++ * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
++ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
++ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
++ * OTHER DEALINGS IN THE SOFTWARE.
++ */
++
++/dts-v1/;
++#include "imx6ul-opos6ul.dtsi"
++
++/ {
++ model = "Armadeus Systems OPOS6UL Module on OPOS6UL Dev board";
++ compatible = "armadeus,opos6uldev", "armadeus,opos6ul", "fsl,imx6ul";
++
++ chosen {
++ stdout-path = &uart1;
++ };
++
++ memory {
++ reg = <0 0>; /* will be filled by U-Boot */
++ };
++
++ backlight {
++ compatible = "gpio-backlight";
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_lcd_backlight>;
++ gpios = <&gpio3 23 GPIO_ACTIVE_HIGH>;
++ default-on;
++ };
++
++ gpio-keys {
++ compatible = "gpio-keys";
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_gpio_keys>;
++
++ user-button {
++ label = "User button";
++ gpios = <&gpio4 7 GPIO_ACTIVE_LOW>;
++ linux,code = <BTN_MISC>;
++ wakeup-source;
++ };
++ };
++
++ leds {
++ compatible = "gpio-leds";
++
++ user_led {
++ label = "User";
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_led>;
++ gpios = <&gpio4 6 GPIO_ACTIVE_HIGH>;
++ linux,default-trigger = "heartbeat";
++ };
++ };
++
++ reg_5v: regulator-5v {
++ compatible = "regulator-fixed";
++ regulator-name = "5V";
++ regulator-min-microvolt = <5000000>;
++ regulator-max-microvolt = <5000000>;
++ };
++
++ reg_usbotg1_vbus: regulator-usbotg1vbus {
++ compatible = "regulator-fixed";
++ regulator-name = "usbotg1vbus";
++ regulator-min-microvolt = <5000000>;
++ regulator-max-microvolt = <5000000>;
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_usbotg1_vbus>;
++ gpio = <&gpio1 5 GPIO_ACTIVE_HIGH>;
++ enable-active-high;
++ };
++
++ reg_usbotg2_vbus: regulator-usbotg2vbus {
++ compatible = "regulator-fixed";
++ regulator-name = "usbotg2vbus";
++ regulator-min-microvolt = <5000000>;
++ regulator-max-microvolt = <5000000>;
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_usbotg2_vbus>;
++ gpio = <&gpio5 9 GPIO_ACTIVE_HIGH>;
++ enable-active-high;
++ };
++};
++
++&can1 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_flexcan1>;
++ xceiver-supply = <®_5v>;
++ status = "okay";
++};
++
++&can2 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_flexcan2>;
++ xceiver-supply = <®_5v>;
++ status = "okay";
++};
++
++&ecspi1 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_ecspi1>;
++ fsl,spi-num-chipselects = <2>;
++ cs-gpios = <&gpio3 26 GPIO_ACTIVE_LOW>, <&gpio4 3 GPIO_ACTIVE_LOW>;
++ status = "okay";
++};
++
++&fec2 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_enet2>;
++ phy-mode = "rmii";
++ phy-reset-duration = <1>;
++ phy-reset-gpios = <&gpio4 1 GPIO_ACTIVE_LOW>;
++ phy-handle = <ðphy2>;
++ phy-supply = <®_3v3>;
++ status = "disabled";
++};
++
++&i2c2 {
++ clock_frequency = <400000>;
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_i2c2>;
++ status = "okay";
++};
++
++&lcdif {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_lcdif>;
++ display = <&display0>;
++ lcd-supply = <®_3v3>;
++ status = "okay";
++
++ display0: display0 {
++ bits-per-pixel = <32>;
++ bus-width = <18>;
++
++ display-timings {
++ timing0: timing0 {
++ clock-frequency = <33000033>;
++ hactive = <800>;
++ vactive = <480>;
++ hback-porch = <96>;
++ hfront-porch = <96>;
++ vback-porch = <20>;
++ vfront-porch = <21>;
++ hsync-len = <64>;
++ vsync-len = <4>;
++ hsync-active = <0>;
++ vsync-active = <0>;
++ de-active = <1>;
++ pixelclk-active = <0>;
++ };
++ };
++ };
++};
++
++&mdio {
++ ethphy2: ethernet-phy@2 {
++ compatible = "ethernet-phy-ieee802.3-c22";
++ reg = <2>;
++ interrupt-parent = <&gpio4>;
++ interrupts = <10 IRQ_TYPE_LEVEL_LOW>;
++ status = "okay";
++ };
++};
++
++&snvs_pwrkey {
++ status = "disabled";
++};
++
++&tsc {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_tsc>;
++ xnur-gpio = <&gpio1 3 GPIO_ACTIVE_LOW>;
++ measure-delay-time = <0xffff>;
++ pre-charge-time = <0xfff>;
++ status = "okay";
++};
++
++&uart1 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_uart1>;
++ status = "okay";
++};
++
++&uart2 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_uart2>;
++ status = "okay";
++};
++
++&usbotg1 {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_usbotg1_id>;
++ vbus-supply = <®_usbotg1_vbus>;
++ dr_mode = "otg";
++ disable-over-current;
++ status = "okay";
++};
++
++&usbotg2 {
++ vbus-supply = <®_usbotg2_vbus>;
++ dr_mode = "host";
++ disable-over-current;
++ status = "okay";
++};
++
++&iomuxc {
++ pinctrl-names = "default";
++ pinctrl-0 = <&pinctrl_gpios>;
++
++ pinctrl_ecspi1: ecspi1grp {
++ fsl,pins = <
++ MX6UL_PAD_LCD_DATA20__ECSPI1_SCLK 0x1b0b0
++ MX6UL_PAD_LCD_DATA21__GPIO3_IO26 0x1b0b0
++ MX6UL_PAD_LCD_DATA22__ECSPI1_MOSI 0x1b0b0
++ MX6UL_PAD_LCD_DATA23__ECSPI1_MISO 0x1b0b0
++ MX6UL_PAD_NAND_DATA01__GPIO4_IO03 0x1b0b0
++ >;
++ };
++
++ pinctrl_enet2: enet2grp {
++ fsl,pins = <
++ MX6UL_PAD_ENET2_RX_ER__ENET2_RX_ER 0x130b0
++ MX6UL_PAD_ENET2_RX_EN__ENET2_RX_EN 0x130b0
++ MX6UL_PAD_ENET2_RX_DATA1__ENET2_RDATA01 0x130b0
++ MX6UL_PAD_ENET2_RX_DATA0__ENET2_RDATA00 0x130b0
++ MX6UL_PAD_ENET2_TX_DATA0__ENET2_TDATA00 0x1b0b0
++ MX6UL_PAD_ENET2_TX_DATA1__ENET2_TDATA01 0x1b0b0
++ MX6UL_PAD_ENET2_TX_EN__ENET2_TX_EN 0x1b0b0
++ /* INT# */
++ MX6UL_PAD_NAND_ALE__GPIO4_IO10 0x1b0b0
++ /* RST# */
++ MX6UL_PAD_NAND_WE_B__GPIO4_IO01 0x130b0
++ MX6UL_PAD_ENET2_TX_CLK__ENET2_REF_CLK2 0x4001b031
++ >;
++ };
++
++ pinctrl_flexcan1: flexcan1grp {
++ fsl,pins = <
++ MX6UL_PAD_UART3_CTS_B__FLEXCAN1_TX 0x0b0b0
++ MX6UL_PAD_UART3_RTS_B__FLEXCAN1_RX 0x0b0b0
++ >;
++ };
++
++ pinctrl_flexcan2: flexcan2grp {
++ fsl,pins = <
++ MX6UL_PAD_UART2_CTS_B__FLEXCAN2_TX 0x0b0b0
++ MX6UL_PAD_UART2_RTS_B__FLEXCAN2_RX 0x0b0b0
++ >;
++ };
++
++ pinctrl_gpios: gpiosgrp {
++ fsl,pins = <
++ MX6UL_PAD_LCD_DATA19__GPIO3_IO24 0x0b0b0
++ MX6UL_PAD_UART3_TX_DATA__GPIO1_IO24 0x0b0b0
++ MX6UL_PAD_UART3_RX_DATA__GPIO1_IO25 0x0b0b0
++ MX6UL_PAD_NAND_RE_B__GPIO4_IO00 0x0b0b0
++ MX6UL_PAD_GPIO1_IO08__GPIO1_IO08 0x0b0b0
++ MX6UL_PAD_UART1_CTS_B__GPIO1_IO18 0x0b0b0
++ MX6UL_PAD_UART1_RTS_B__GPIO1_IO19 0x0b0b0
++ MX6UL_PAD_GPIO1_IO09__GPIO1_IO09 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER0__GPIO5_IO00 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER1__GPIO5_IO01 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER2__GPIO5_IO02 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER3__GPIO5_IO03 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER4__GPIO5_IO04 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER5__GPIO5_IO05 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER6__GPIO5_IO06 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER7__GPIO5_IO07 0x0b0b0
++ MX6UL_PAD_SNVS_TAMPER8__GPIO5_IO08 0x0b0b0
++ >;
++ };
++
++ pinctrl_gpio_keys: gpio_keysgrp {
++ fsl,pins = <
++ MX6UL_PAD_NAND_DATA05__GPIO4_IO07 0x0b0b0
++ >;
++ };
++
++ pinctrl_i2c2: i2c2grp {
++ fsl,pins = <
++ MX6UL_PAD_UART5_RX_DATA__I2C2_SDA 0x4001b8b0
++ MX6UL_PAD_UART5_TX_DATA__I2C2_SCL 0x4001b8b0
++ >;
++ };
++
++ pinctrl_lcd_backlight: lcd_backlightgrp {
++ fsl,pins = <
++ MX6UL_PAD_LCD_DATA18__GPIO3_IO23 0x0b0b0
++ >;
++ };
++
++ pinctrl_lcdif: lcdifgrp {
++ fsl,pins = <
++ MX6UL_PAD_LCD_CLK__LCDIF_CLK 0x100b1
++ MX6UL_PAD_LCD_ENABLE__LCDIF_ENABLE 0x100b1
++ MX6UL_PAD_LCD_HSYNC__LCDIF_HSYNC 0x100b1
++ MX6UL_PAD_LCD_VSYNC__LCDIF_VSYNC 0x100b1
++ MX6UL_PAD_LCD_DATA00__LCDIF_DATA00 0x100b1
++ MX6UL_PAD_LCD_DATA01__LCDIF_DATA01 0x100b1
++ MX6UL_PAD_LCD_DATA02__LCDIF_DATA02 0x100b1
++ MX6UL_PAD_LCD_DATA03__LCDIF_DATA03 0x100b1
++ MX6UL_PAD_LCD_DATA04__LCDIF_DATA04 0x100b1
++ MX6UL_PAD_LCD_DATA05__LCDIF_DATA05 0x100b1
++ MX6UL_PAD_LCD_DATA06__LCDIF_DATA06 0x100b1
++ MX6UL_PAD_LCD_DATA07__LCDIF_DATA07 0x100b1
++ MX6UL_PAD_LCD_DATA08__LCDIF_DATA08 0x100b1
++ MX6UL_PAD_LCD_DATA09__LCDIF_DATA09 0x100b1
++ MX6UL_PAD_LCD_DATA10__LCDIF_DATA10 0x100b1
++ MX6UL_PAD_LCD_DATA11__LCDIF_DATA11 0x100b1
++ MX6UL_PAD_LCD_DATA12__LCDIF_DATA12 0x100b1
++ MX6UL_PAD_LCD_DATA13__LCDIF_DATA13 0x100b1
++ MX6UL_PAD_LCD_DATA14__LCDIF_DATA14 0x100b1
++ MX6UL_PAD_LCD_DATA15__LCDIF_DATA15 0x100b1
++ MX6UL_PAD_LCD_DATA16__LCDIF_DATA16 0x100b1
++ MX6UL_PAD_LCD_DATA17__LCDIF_DATA17 0x100b1
++ >;
++ };
++
++ pinctrl_led: ledgrp {
++ fsl,pins = <
++ MX6UL_PAD_NAND_DATA04__GPIO4_IO06 0x0b0b0
++ >;
++ };
++
++ pinctrl_tsc: tscgrp {
++ fsl,pins = <
++ MX6UL_PAD_GPIO1_IO01__GPIO1_IO01 0xb0
++ MX6UL_PAD_GPIO1_IO02__GPIO1_IO02 0xb0
++ MX6UL_PAD_GPIO1_IO03__GPIO1_IO03 0xb0
++ MX6UL_PAD_GPIO1_IO04__GPIO1_IO04 0xb0
++ >;
++ };
++
++ pinctrl_uart1: uart1grp {
++ fsl,pins = <
++ MX6UL_PAD_UART1_TX_DATA__UART1_DCE_TX 0x1b0b1
++ MX6UL_PAD_UART1_RX_DATA__UART1_DCE_RX 0x1b0b1
++ >;
++ };
++
++ pinctrl_uart2: uart2grp {
++ fsl,pins = <
++ MX6UL_PAD_UART2_TX_DATA__UART2_DCE_TX 0x1b0b1
++ MX6UL_PAD_UART2_RX_DATA__UART2_DCE_RX 0x1b0b1
++ >;
++ };
++
++ pinctrl_usbotg1_id: usbotg1_idgrp {
++ fsl,pins = <
++ MX6UL_PAD_GPIO1_IO00__ANATOP_OTG1_ID 0x1b0b0
++ >;
++ };
++
++ pinctrl_usbotg1_vbus: usbotg1_vbusgrp {
++ fsl,pins = <
++ MX6UL_PAD_GPIO1_IO05__GPIO1_IO05 0x1b0b0
++ >;
++ };
++
++ pinctrl_usbotg2_vbus: usbotg2_vbusgrp {
++ fsl,pins = <
++ MX6UL_PAD_SNVS_TAMPER9__GPIO5_IO09 0x1b0b0
++ >;
++ };
++};
+--
+2.3.6
diff --git a/software/uboot_recover/opos6ul-u-boot.img b/software/uboot_recover/opos6ul-u-boot.img
new file mode 100644
index 0000000..1c3b154
Binary files /dev/null and b/software/uboot_recover/opos6ul-u-boot.img differ
diff --git a/software/uboot_recover/opos6ul-u-boot.spl b/software/uboot_recover/opos6ul-u-boot.spl
new file mode 100644
index 0000000..3993969
Binary files /dev/null and b/software/uboot_recover/opos6ul-u-boot.spl differ
diff --git a/software/uboot_recover/apf6_recovery.py b/software/uboot_recover/opos6ul_recovery.py
similarity index 91%
copy from software/uboot_recover/apf6_recovery.py
copy to software/uboot_recover/opos6ul_recovery.py
index 885b6f9..8a09c67 100644
--- a/software/uboot_recover/apf6_recovery.py
+++ b/software/uboot_recover/opos6ul_recovery.py
@@ -1,5 +1,5 @@
#
# APF6 bootloader recovering tool
#
# Copyright (C) 2014 Armadeus Project
#
@@ -84,21 +84,21 @@ if __name__ == "__main__":
BR_IMAGES_PATH = "../../buildroot/output/images"
USB_DOWNLOAD_APP = BR_HOST_PATH + "/usr/bin/imx_usb"
SERIAL_DOWNLOAD_APP = "sb"
- U_BOOT_SPL = "apf6-u-boot.spl"
- U_BOOT_IMG = "apf6-u-boot.img"
+ U_BOOT_SPL = "opos6ul-u-boot.spl"
+ U_BOOT_IMG = "opos6ul-u-boot.img"
SPEED = 115200
- print color.BOLD + "\n--- APF6 Bootstrap Tool ---\n"
+ print color.BOLD + "\n--- OPOS6UL Bootstrap Tool ---\n"
print "Procedure to follow:"
print "1] Be sure to:"
- print " * have built the APF6 BSP (make apf6_defconfig; make),"
+ print " * have built the OPOS6UL BSP (make opos6ul_defconfig; make),"
print " * have \"sb\" tool installed on your PC (on Ubuntu: sudo apt-get install lrzsz),"
print " * have launched this script as root (sudo)."
print "2] Power off your board, close all serial terminal sessions, remove all USB cables"
print "3] Take jumper off BOOT0 pins and put it on BOOT1 pins."
print "4] Power on your board"
- print "5] Connect a USB cable from your PC to the APF6Dev OTG miniUSB connector"
- print "6] Connect a USB cable from your PC to the APF6Dev console miniUSB connector"
+ print "5] Connect a USB cable from your PC to the OPOS6ULDev OTG miniUSB connector"
+ print "6] Connect a USB cable from your PC to the OPOS6ULDev console miniUSB connector"
print ""
port = raw_input('--- Then, enter serial port number or device name to use for console (/dev/ttyUSB0 under Linux (default) or COMx under Window$): ' + color.END)
if port == '':
@@ -119,7 +119,7 @@ if __name__ == "__main__":
sys.exit(1)
try:
- subprocess.check_call([USB_DOWNLOAD_APP, "-c", BR_HOST_PATH + "/usr/share/imx_usb_loader/", U_BOOT_SPL])
+ subprocess.check_call([USB_DOWNLOAD_APP, "-c", BR_HOST_PATH + "/etc/imx-loader.d/", U_BOOT_SPL])
subprocess.check_call(SERIAL_DOWNLOAD_APP + " -k " + U_BOOT_IMG + " > " + port + " < " + port, shell=True)
except subprocess.CalledProcessError:
print color.RED + "Error: Loading U-Boot binaries failed !" + color.END
@@ -1,5 +1,5 @@
#
-# APF6 bootloader recovering tool
+# OPOS6UL bootloader recovering tool
#
# Copyright (C) 2014 Armadeus Project
hooks/post-receive
--
armadeus
|